## Version 0.0.72

This new version includes several enhancements to the Zotero module, improvements to the QueryBot, and updates to the pre-commit hooks. It also introduces a new Jupyter notebook for outlines models and enables package publishing to PyPI.

### New Features

- Added code to retrieve the title of a specific article from the Zotero library using the article's unique identifier (5921df) (Eric Ma)
- Added support for default similarity top ks in QueryBot based on the OPENAI_DEFAULT_MODEL environment variable (ae392f) (Eric Ma)
- Enhanced the ZoteroLibrary class by adding an `articles_only` filter and a `key_title_map` function (85a223) (Eric Ma)
- Improved the get_key function documentation in the Zotero module (89b6bc) (Eric Ma)
- Streamlined the paper selection process in the Zotero CLI by introducing a new PaperTitleCompleter for more efficient paper selection (1122e6) (Eric Ma)
- Improved handling of similarity_top_k in QueryBot and refactored index creation (acc6e8) (Eric Ma)
- Added 'sh' dependency to environment.yml and pyproject.toml files (5e23f9) (Eric Ma)
- Added execution of pre-commit hooks before committing changes (82979d) (Eric Ma)
- Added a new class, PaperTitleCompleter, to provide completion suggestions for paper titles in the Zotero module (3fac26) (Eric Ma)
- Updated pre-commit config and notebooks (b077aa) (Eric Ma)
- Extended the ruff pre-commit hook to also check python and jupyter files (4ae772) (Eric Ma)
- Added nltk as a transitive dependency via llama_index in the environment.yml file (2bd392) (Eric Ma)
- Introduced a new pre-commit hook, ruff, to the .pre-commit-config.yaml file (c7c5bc) (Eric Ma)
- Enabled package publishing to PyPI (baca5c) (Eric Ma)

### Bug Fixes

- Fixed assertion in test_magic_load_doc_txt function (ef4b3e) (Eric Ma)

### Refactors

- Simplified the docstring in the doc_processor module and modified the document loading (fab218) (Eric Ma)
- Replaced 'index' with 'vector_index' in QueryBot class and refactored related methods (cfb284) (Eric Ma)

### Dependencies

- Bumped version: 0.0.71 → 0.0.72 (d37eab) (github-actions)
- Added "pre-commit" to the list of dependencies in pyproject.toml (687645) (Eric Ma)
- Updated dependencies in environment.yml (7cb9a6) (Eric Ma)

### Other

- Updated the version of the black pre-commit hook and removed the flake8 and isort pre-commit hooks (9fca51) (Eric Ma)
- Added a comment to clarify that GH Actions is allowed to write to the repository in the release-python-package workflow (bcf534) (Eric Ma)
- Introduced a new Jupyter notebook 'outlines_models.ipynb' in the 'scratch_notebooks' directory (746273) (Eric Ma)
